"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AHResqueUIInitializer = void 0;
const actionhero_1 = require("actionhero");
class AHResqueUIInitializer extends actionhero_1.Initializer {
    constructor() {
        super();
        this.name = "ah-resque-ui";
        this.loadPriority = 99999999;
    }
    async initialize() {
        /* ----- Route Injection ----- */
        actionhero_1.route.registerRoute("get", "/:apiVersion/resque/redisInfo", "resque:redisInfo");
        actionhero_1.route.registerRoute("get", "/:apiVersion/resque/resqueDetails", "resque:resqueDetails");
        actionhero_1.route.registerRoute("get", "/:apiVersion/resque/queued", "resque:queued");
        actionhero_1.route.registerRoute("get", "/:apiVersion/resque/loadWorkerQueues", "resque:loadWorkerQueues");
        actionhero_1.route.registerRoute("get", "/:apiVersion/resque/resqueFailedCount", "resque:resqueFailedCount");
        actionhero_1.route.registerRoute("get", "/:apiVersion/resque/resqueFailed", "resque:resqueFailed");
        actionhero_1.route.registerRoute("get", "/:apiVersion/resque/delayedjobs", "resque:delayedjobs");
        actionhero_1.route.registerRoute("get", "/:apiVersion/resque/locks", "resque:locks");
        actionhero_1.route.registerRoute("post", "/:apiVersion/resque/removeFailed", "resque:removeFailed");
        actionhero_1.route.registerRoute("post", "/:apiVersion/resque/retryAndRemoveFailed", "resque:retryAndRemoveFailed");
        actionhero_1.route.registerRoute("post", "/:apiVersion/resque/removeAllFailed", "resque:removeAllFailed");
        actionhero_1.route.registerRoute("post", "/:apiVersion/resque/retryAndRemoveAllFailed", "resque:retryAndRemoveAllFailed");
        actionhero_1.route.registerRoute("post", "/:apiVersion/resque/forceCleanWorker", "resque:forceCleanWorker");
        actionhero_1.route.registerRoute("post", "/:apiVersion/resque/delQueue", "resque:delQueue");
        actionhero_1.route.registerRoute("post", "/:apiVersion/resque/delDelayed", "resque:delDelayed");
        actionhero_1.route.registerRoute("post", "/:apiVersion/resque/runDelayed", "resque:runDelayed");
        actionhero_1.route.registerRoute("post", "/:apiVersion/resque/delLock", "resque:delLock");
        /* ----- Proxy Middleware ----- */
        const middleware = {
            name: "ah-resque-ui-proxy-middleware",
            global: false,
            preProcessor: async (data) => { },
            postProcessor: async (data) => { },
        };
        if (actionhero_1.config["ah-resque-ui"].middleware &&
            actionhero_1.config["ah-resque-ui"].middleware.length > 0) {
            middleware.preProcessor = async (data) => {
                for (const middlewareName of actionhero_1.config["ah-resque-ui"].middleware) {
                    const middleware = actionhero_1.api.actions.middleware[middlewareName];
                    if (typeof middleware.preProcessor === "function") {
                        await middleware.preProcessor(data);
                    }
                }
            };
            middleware.postProcessor = async (data) => {
                for (const middlewareName of actionhero_1.config["ah-resque-ui"].middleware) {
                    const middleware = actionhero_1.api.actions.middleware[middlewareName];
                    if (typeof middleware.postProcessor === "function") {
                        await middleware.postProcessor(data);
                    }
                }
            };
        }
        actionhero_1.action.addMiddleware(middleware);
    }
}
exports.AHResqueUIInitializer = AHResqueUIInitializer;
